@@ -7,16 +7,16 @@ import warnings
 from django.core.signals import got_request_exception
 from django.db import  transaction
 
-from sentry import conf
+from sentry.conf import settings
 
 logger = logging.getLogger('sentry.errors')
 
 _client = (None, None)
 def get_client():
     global _client
-    if _client[0] != conf.CLIENT:
-        module, class_name = conf.CLIENT.rsplit('.', 1)
-        _client = (conf.CLIENT, getattr(__import__(module, {}, {}, class_name), class_name)())
+    if _client[0] != settings.CLIENT:
+        module, class_name = settings.CLIENT.rsplit('.', 1)
+        _client = (settings.CLIENT, getattr(__import__(module, {}, {}, class_name), class_name)())
     return _client[1]
 client = get_client()
 
@@ -25,7 +25,7 @@ def sentry_exception_handler(request=None, **kwargs):
     try:
         exc_type, exc_value, exc_traceback = sys.exc_info()
 
-        if conf.DEBUG or getattr(exc_type, 'skip_sentry', False):
+        if settings.DEBUG or getattr(exc_type, 'skip_sentry', False):
             return
 
         if transaction.is_dirty():
