@@ -9,5 +9,6 @@ urlpatterns = patterns('',
     url(r'^trigger-500-decorated$', 'sentry.tests.views.decorated_raise_exc', name='sentry-raise-exc-decor'),
     url(r'^trigger-500-django$', 'sentry.tests.views.django_exc', name='sentry-django-exc'),
     url(r'^trigger-500-template$', 'sentry.tests.views.template_exc', name='sentry-template-exc'),
-    url(r'', include('sentry.urls')),
+    url(r'^trigger-500-log-request$', 'sentry.tests.views.logging_request_exc', name='sentry-log-request-exc'),
+    url(r'', include('sentry.web.urls')),
 )
\ No newline at end of file
